@@ -57,6 +57,8 @@ public class MavenArtifactRepository
 
     private List<ArtifactRepository> mirroredRepositories = Collections.emptyList();
 
+    private boolean blocked;
+
     public MavenArtifactRepository()
     {
     }
@@ -160,6 +162,8 @@ public class MavenArtifactRepository
             sb.append( ", update => " ).append( releases.getUpdatePolicy() ).append( "]\n" );
         }
 
+        sb.append( "   blocked: " ).append( isBlocked() ).append( '\n' );
+
         return sb.toString();
     }
 
@@ -414,4 +418,14 @@ public class MavenArtifactRepository
         }
     }
 
+    public boolean isBlocked()
+    {
+        return blocked;
+    }
+
+    public void setBlocked( boolean blocked )
+    {
+        this.blocked = blocked;
+    }
+
 }
